..
    SPDX-License-Identifier: AGPL-3.0-or-later
    Copyright (C) 2025  Dionisis Toulatos

MQTT
####

.. automodule:: nirahmq.mqtt
    :members:

.. autoattribute:: nirahmq.mqtt.Topic

    A custom type alias used by :py:mod:`nirahmq` to validate a string is a valid MQTT topic.
